@@ -1,5 +1,5 @@
 `VELOCITY.SEISN`<-
-function(TH, sel=1:length(TH$JSTR), inst=1, Kal=Kal, FILT=list(ON=TRUE, fl=1/30, fh=7.0, type="HP", proto="BU") )
+function(TH, sel=1:length(TH$JSTR), inst=1, Kal=Kal, FILT=list(ON=FALSE, fl=1/30, fh=7.0, type="HP", proto="BU") )
 {
   ########  convert the seismic to velocity
   ###  inst refers to the instrument response described in Kal
@@ -14,10 +14,20 @@ function(TH, sel=1:length(TH$JSTR), inst=1, Kal=Kal, FILT=list(ON=TRUE, fl=1/30,
 
 if(is.logical(sel)) { sel = which(sel) }
   
-    if(missing(FILT)) { FILT = list(ON=TRUE, fl=1/30, fh=7.0, type="HP", proto="BU")  }
+    if(missing(FILT)) { FILT = list(ON=FALSE, fl=1/30, fh=7.0, type="HP", proto="BU")  }
+
+  #############  this filter option is not available at this time, use FILT.SEISN
  
   Calibnew = c(1,1.0, 0.0 )
 
+  if(FILT$ON==TRUE)
+    {
+
+      print("Filter option not available, use FILT.SEISN")
+ 
+    }
+
+
   
  for(i in 1:length(sel))
    {
@@ -29,8 +39,12 @@ if(is.logical(sel)) { sel = which(sel) }
      if(ins==0) next
      
      y = TH$JSTR[[ii]]
+#############################    for now, do not analyse wigs  that have NA's
+     if(any(is.na(y)))
+       {
+         next
 
-
+       }
      
      y = y-mean(y)
      y = detrend(y)
@@ -47,6 +61,11 @@ if(is.logical(sel)) { sel = which(sel) }
      TH$units[ii] = "m/s"
      
    }
+
+  proc = paste(sep=" ", "VELOCITY.SEISN", "FILT", FILT$ON, FILT$fl, FILT$fh, FILT$type, FILT$proto) 
+
+  TH$process = c(TH$process, proc)
+  
  invisible(TH)
 }
 
